Package: idar
Version: 1.7
Date: 2026-04-13
Title: Individual Diversity-Area Relationships
Authors@R: c(person(given = "Marcelino",
                        family = "de la Cruz",
                        role = c("aut", "cre"),
                        email = "marcelino.delacruz@urjc.es",
                        comment = c(ORCID ="0000-0002-9080-4525")),
			person(given ="Etienne", 
                        family = "Laliberté",
                        role = c("ctb")))
Depends: picante, spatstat (>= 2.0-0)
Imports: ade4, ape, spatstat.geom, spatstat.explore, spatstat.random
Suggests: ecespa, vegan
Description: Computes and tests individual (species, phylogenetic and functional) diversity-area relationships, i.e., how species-, phylogenetic- and functional-diversity varies with spatial scale around the individuals of some species in a community. See applications of these methods in Wiegand et al. (2007) <doi:10.1073/pnas.0705621104> or Chacon-Labella et al. (2016) <doi:10.1007/s00442-016-3547-z>.
License: GPL (>= 2)
Encoding: UTF-8
NeedsCompilation: yes
Packaged: 2026-04-11 11:15:06 UTC; user
Author: Marcelino de la Cruz [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-9080-4525>),
  Etienne Laliberté [ctb]
Maintainer: Marcelino de la Cruz <marcelino.delacruz@urjc.es>
Repository: CRAN
Date/Publication: 2026-04-14 12:00:02 UTC
Built: R 4.5.2; aarch64-apple-darwin20; 2026-04-15 05:20:05 UTC; unix
Archs: idar.so.dSYM
